var AutoSelect = function()
{
	var autoselect = {};
	var debug = 0;
	var hasInitProtocols = false;

	// Page initialization
	autoselect.initPage = function()
	{
		Buttons.addClickHandler('close', App.closeWindow);
		Buttons.addClickHandler('btnOk', autoselect.doAutoSelect);
		
		Events.addEventHandler('quantity_regular', 'keypress', Events.numberOnly);
		Events.addEventHandler('quality_score', 'keypress', Events.numberOnly);
		
		Events.addEventHandler('preNormalized.0', 'click', autoselect.setPreNormalize);
		Events.addEventHandler('preNormalized.1', 'click', autoselect.setPreNormalize);
		
		var isNeoPrep = Data.int('page-data', 'is-neoprep');
		Events.addEventHandler('normalizationProtocol', 'change', autoselect.protocolOnChange);
		Reggie.loadProtocols('RNA_NORMALIZATION_PROTOCOL', 'normalizationProtocol', 'LIBPREP_TARGET,RNA_TARGET_AMOUNT,RNA_MINIMAL_AMOUNT,RNA_TARGET_VOLUME', isNeoPrep ? 'NeoPrep' : 'Manual');
		autoselect.setPreNormalize();
	}

	autoselect.setPreNormalize = function()
	{
		var frm = document.forms['options'];
		var preNormalize = frm.preNormalized[1].checked;
		
		Doc.element('normalizationProtocol').disabled = !preNormalize;
		Doc.element('remainingQuantity').disabled = preNormalize;
		Doc.element('quantity_regular').disabled = preNormalize;
		Doc.element('qualityScore').disabled = preNormalize;
		Doc.element('quality_score').disabled = preNormalize;
		Doc.element('reProcess').disabled = preNormalize;
		Doc.element('flag').disabled = preNormalize;	
	}
	
	autoselect.protocolOnChange = function()
	{
		var frm = document.forms['options'];

		if (!hasInitProtocols)
		{
			hasInitProtocols = true;
			var selectedProtocol = Data.int('page-data', 'protocol-id');
			
			if (frm.normalizationProtocol.length == 0)
			{
				Wizard.setFatalError('No RNA normalization protocols found. Please ask the server administrator to create at least one protocol.');
				return;
			}
			
			for (var i=0; i < frm.normalizationProtocol.length; i++)
			{
				var p = frm.normalizationProtocol[i].item;
				var unit = 'µg';
				var factor = 1;
				if (p.RNATargetAmount < 0.5)
				{
					unit = 'ng';
					factor = 1000;
				}
				
				var text = p.name + ' (';
				if (p.RNAMinimalAmount) text += Reggie.formatNumber(p.RNAMinimalAmount * factor, '', 1) + '-';
				text += p.RNATargetAmount ? Reggie.formatNumber(p.RNATargetAmount * factor, '', 1) : '? ';
				text += unit;
				text += ' in '+(p.RNATargetVolume || '? ')+'µl)';
				frm.normalizationProtocol[i].text = text;
				
				if (p.id == selectedProtocol) frm.normalizationProtocol.selectedIndex = i;
			}
			
		}
	}

	
	autoselect.doAutoSelect = function()
	{
		var options = {};
		var frm = document.forms['options'];
		
		var preNormalize = frm.preNormalized[1].checked;
		var startDate = frm.startDate.value;
		if (startDate && !Dates.isDate(startDate, 'yyyyMMdd'))
		{
			Forms.showNotification('startDate', 'Not a valid date');
			return;
		}
		
		if (!preNormalize)
		{
			var qRegular = parseFloat(frm.quantity_regular.value);
			if (!(qRegular > 0))
			{
				Forms.showNotification('quantity_regular', 'Remaining quantity must be a number >0');
				return;
			}
			
			var qualityScore = parseFloat(frm.quality_score.value);
			if (!(qualityScore > 0))
			{
				Forms.showNotification('quality_score', 'RQS/RIN must be a number >0')
				return;
			}
		}
		else
		{
			options.normalizationProtocol = parseInt(frm.normalizationProtocol.value);
		}
		

		if (startDate) options.startDate = startDate;
		if (preNormalize)
		{
			options.preNormalized = 1;
		}
		else
		{
			if (frm.remainingQuantity.checked) options.remainingQuantity = qRegular;
			if (frm.qualityScore.checked) options.qualityScore = qualityScore;
			if (frm.flag.checked) options.flag = 1;
			if (frm.reProcess.checked) options.reProcess = 1;
		}
		
		options.ignore = Data.json('page-data', 'ignore');
		
		var url = '../MRna.servlet?ID='+App.getSessionId();
		url += '&cmd=AutoSelectRnaForMRna&numToSelect='+Data.get('page-data', 'num-to-select');
		
		Wizard.showLoadingAnimation('Finding RNA. Please wait...');
		Wizard.asyncJsonRequest(url, autoselect.rnaSelected, 'POST', JSON.stringify(options));
	}

	autoselect.rnaSelected = function(response)
	{
		var rna = response.rna;
		if (rna.length == 0)
		{
			Doc.addClass('btnOk', 'disabled');
			Wizard.setFatalError('Could not find any unprocessed RNA at this time.');
			return;
		}
		
		window.opener.SelectRna.rnaSelected(response);
		window.close();
	}

	return autoselect;
}();

Doc.onLoad(AutoSelect.initPage);

